%global srcname setuptools

#  WARNING  When bootstrapping, disable tests as well,
#           because tests need pip.
%bcond_with bootstrap

# Disabled for now as pytest-fixture-config is requires which is imcompatible with pytest >= 4.0.0
%bcond_with tests

%if %{without bootstrap}
%global python_wheelname %{srcname}-%{version}-py3-none-any.whl
%global python3_record %{python3_sitelib}/%{srcname}-%{version}.dist-info/RECORD
%endif
%global python_wheeldir %{_datadir}/python-wheels

Summary:    Easily build and distribute Python packages
Name:       python-%{srcname}
Version:    56.2.0
%define subrel 1
Release:    %mkrel 1
License:    MIT
Group:      Development/Python
Url:        https://pypi.python.org/pypi/setuptools
Source0:    %{pypi_source %{srcname} %{version}}
Patch1:     CVE-2022-40897-ReDos.patch
BuildArch:  noarch

%description
A collection of enhancements to the Python distutils that allow
you to more easily build and distribute Python packages, especially
ones that have dependencies on other packages.

%package -n python3-%{srcname}
Summary:    Easily build and distribute Python3 packages
Group:      Development/Python

BuildRequires:  pkgconfig(python3)
%if %{with tests}
BuildRequires:  python3dist(pytest)
BuildRequires:  python3dist(mock)
%endif
%if %{without bootstrap}
BuildRequires:  python3-pip
BuildRequires:  python3-wheel
%else
Provides:       python%{python3_pkgversion}dist(setuptools) = %{version}
Provides:	python%{python3_version}dist(setuptools) = %{version}
%endif
Requires:   python3-pkg-resources

Provides:   python3-setuptools-devel = %{version}-%{release}
Obsoletes:  python3-setuptools-devel < 0.7

Provides:   python3-distribute = %{version}-%{release}
Obsoletes:  python3-distribute < 0.7
Conflicts:      python2-setuptools < %{version}-%{release}

%{?python_provide:%python_provide python3-%{srcname}}

%description -n python3-%{srcname}
A collection of enhancements to the Python 3 distutils that allow
you to more easily build and distribute Python 3 packages, especially
ones that have dependencies on other packages.

%package -n python3-pkg-resources
Summary: Runtime module to access python 3 resources
Group:      Development/Python

%description -n python3-pkg-resources
Module used to find and manage Python 3 package/version dependencies and access
bundled files and resources, including those inside of zipped .egg files.

%if %{without bootstrap}
%package wheel
Summary:        The setuptools wheel

%description wheel
A Python wheel of setuptools to use with venv.
%endif


%prep
%autosetup -p1 -n %{srcname}-%{version}
%if %{without bootstrap}
# If we don't have setuptools installed yet, we use the pre-generated .egg-info
# See https://github.com/pypa/setuptools/pull/2543
# And https://github.com/pypa/setuptools/issues/2550
rm -r %{srcname}.egg-info
%endif

# Strip shbang
find setuptools pkg_resources -name \*.py | xargs sed -i -e '1 {/^#!\//d}'
# Remove bundled exes
rm -f setuptools/*.exe
# These tests require internet connection
rm setuptools/tests/test_integration.py 
# We don't do linting or coverage here
sed -i pytest.ini -e 's/ --flake8//' \
                  -e 's/ --cov//'

# https://github.com/pypa/setuptools/discussions/2607
rm pyproject.toml

%build
%if %{without bootstrap}
%py3_build_wheel
%else
%py3_build
%endif


%install
%if %{without bootstrap}
%py3_install_wheel %{python_wheelname}
%else
%py3_install
%endif

# This is not installed (in 45.2.0 anyway), but better be safe than sorry
rm -rf %{buildroot}%{python3_sitelib}/{setuptools,pkg_resources}/tests

%if %{without bootstrap}
sed -i '/^setuptools\/tests\//d' %{buildroot}%{python3_record}
%endif

find %{buildroot}%{python3_sitelib} -name '*.exe' | xargs rm -f

# Don't ship these
rm -r docs/{conf.py,_*}

%if %{without bootstrap}
mkdir -p %{buildroot}%{python_wheeldir}
install -p dist/%{python_wheelname} -t %{buildroot}%{python_wheeldir}
%endif

%if %{with tests}
%check
# --ignore=pavement.py:
#   pavement.py is only used by upstream to do releases and vendoring, we don't ship it
PYTHONPATH=$(pwd) %pytest --ignore=pavement.py
%endif


%files -n python3-setuptools
%license LICENSE
%doc docs/* CHANGES.rst README.rst
%{python3_sitelib}/setuptools*/
%{python3_sitelib}/_distutils_hack/
%{python3_sitelib}/distutils-precedence.pth

%files -n python3-pkg-resources
%{python3_sitelib}/pkg_resources/

%if %{without bootstrap}
%files wheel
%license LICENSE
# we own the dir for simplicity
%dir %{python_wheeldir}/
%{python_wheeldir}/%{python_wheelname}
%endif


%changelog
* Fri Jun 30 2023 daviddavid <daviddavid> 56.2.0-1.1.mga8
+ Revision: 1963319
- add opensuse patch to fix CVE-2022-40897 (mga#31421)

* Sun Jul 25 2021 wally <wally> 56.2.0-1.mga8
+ Revision: 1737738
- new version 56.2.0 (mga#29288)

* Mon Nov 02 2020 guillomovitch <guillomovitch> 50.3.2-1.mga8
+ Revision: 1641712
- new version 50.3.2

* Tue Sep 15 2020 guillomovitch <guillomovitch> 50.3.0-1.mga8
+ Revision: 1626693
- new version 50.3.0

* Mon Jul 20 2020 wally <wally> 47.3.1-1.mga8
+ Revision: 1607459
- new version 47.3.1

* Tue Jun 09 2020 daviddavid <daviddavid> 46.4.0-1.mga8
+ Revision: 1591158
- new version: 46.4.0

* Sat Apr 04 2020 daviddavid <daviddavid> 46.1.3-1.mga8
+ Revision: 1564252
- new version: 46.1.3

* Tue Mar 31 2020 daviddavid <daviddavid> 46.0.0-1.mga8
+ Revision: 1562591
- new version: 46.0.0

* Fri Feb 28 2020 wally <wally> 45.2.0-1.mga8
+ Revision: 1552034
- new version 45.2.0

* Tue Feb 18 2020 umeabot <umeabot> 41.6.0-2.mga8
+ Revision: 1538218
- Mageia 8 Mass Rebuild

* Sat Nov 16 2019 daviddavid <daviddavid> 41.6.0-1.mga8
+ Revision: 1461180
- new version: 41.6.0

* Thu Sep 12 2019 wally <wally> 41.2.0-1.mga8
+ Revision: 1440019
- new version 41.2.0

* Thu Sep 05 2019 tv <tv> 41.0.0-4.mga8
+ Revision: 1437510
- add conflicts b/c of:
  file /usr/bin/easy_install from install of python2-setuptools-41.0.0-1.mga7
  conflicts with file from package python3-setuptools-41.0.0-3.mga8

* Tue Sep 03 2019 wally <wally> 41.0.0-3.mga8
+ Revision: 1436768
- non-bootstrap build for python3.8

* Tue Sep 03 2019 wally <wally> 41.0.0-2.mga8
+ Revision: 1436703
- bootstrap build for python3.8
- drop python2 support

* Sat Apr 20 2019 wally <wally> 41.0.0-1.mga7
+ Revision: 1393858
- new version 41.0.0

* Sun Jan 13 2019 wally <wally> 40.6.3-4.mga7
+ Revision: 1355912
- don't use bundled egg-info when building
- don't own python3's __pycache__ dir

* Fri Jan 04 2019 wally <wally> 40.6.3-3.mga7
+ Revision: 1349213
- disable bootstrap

* Fri Jan 04 2019 wally <wally> 40.6.3-2.mga7
+ Revision: 1349177
- bootstrap build for python3.7

* Tue Jan 01 2019 wally <wally> 40.6.3-1.mga7
+ Revision: 1348196
- new version 40.6.3
- create python-setuptools-wheel (sync .spec a bit with Fedora)

* Tue Jan 01 2019 wally <wally> 40.6.2-1.mga7
+ Revision: 1348121
- new version 40.6.2

* Tue Jan 01 2019 wally <wally> 40.4.3-1.mga7
+ Revision: 1347975
- new version 40.4.3

* Tue Sep 25 2018 tv <tv> 39.2.0-6.mga7
+ Revision: 1304901
- rebuild with wheel

* Tue Sep 25 2018 tv <tv> 39.2.0-5.mga7
+ Revision: 1304875
- fix BR for bootstrapping: pythonXdist(pip) -> pythonX-pip + disable wheel again
- move provides out of %%buid_wheel
- rebuild with wheel

* Mon Sep 24 2018 tv <tv> 39.2.0-3.mga7
+ Revision: 1303662
- rebuild w/o wheel

* Thu Sep 20 2018 umeabot <umeabot> 39.2.0-2.mga7
+ Revision: 1290020
- Mageia 7 Mass Rebuild

* Sun May 20 2018 kekepower <kekepower> 39.2.0-1.mga7
+ Revision: 1230798
- Update to version 39.2.0
- BR s/egg/dist
- Use python_provide

* Tue Mar 20 2018 kekepower <kekepower> 39.0.1-1.mga7
+ Revision: 1210565
- Disable patch
- Update to version 39.0.1

* Mon Feb 19 2018 kekepower <kekepower> 38.5.1-1.mga7
+ Revision: 1203268
- Update to version 38.5.1
- Rediffed patch

* Mon Oct 02 2017 daviddavid <daviddavid> 36.2.4-6.mga7
+ Revision: 1162492
- fix %%files pkg name for python2-setuptools

* Mon Oct 02 2017 daviddavid <daviddavid> 36.2.4-5.mga7
+ Revision: 1162484
- rename python-setuptools to python2-setuptools
- rename python-pkg-resources to python2-pkg-resources

* Thu Aug 03 2017 tv <tv> 36.2.4-4.mga7
+ Revision: 1134299
- rebuild for new python

* Sat Jul 29 2017 philippem <philippem> 36.2.4-3.mga7
+ Revision: 1132528
- Rebuild for Python 3.6 with wheel

* Sat Jul 29 2017 philippem <philippem> 36.2.4-2.mga7
+ Revision: 1132511
- revert use makedirs

* Fri Jul 28 2017 philippem <philippem> 36.2.4-1.mga7
+ Revision: 1132086
- update to 36.2.4, first step for Python 3.6.2

* Mon Feb 01 2016 daviddavid <daviddavid> 19.6.2-1.mga6
+ Revision: 929705
- new version: 19.6.2

* Tue Jan 26 2016 daviddavid <daviddavid> 19.6-1.mga6
+ Revision: 927898
- new version: 19.6

* Tue Jan 19 2016 daviddavid <daviddavid> 19.4-1.mga6
+ Revision: 925912
- new version: 19.4

* Thu Nov 26 2015 philippem <philippem> 18.6.1-1.mga6
+ Revision: 906237
- update to 18.6.1

* Wed Oct 07 2015 joequant <joequant> 18.3.2-3.mga6
+ Revision: 886667
- upgrade to python 3.5

* Tue Sep 22 2015 philippem <philippem> 18.3.2-2.mga6
+ Revision: 882292
- Rebuild as wheel for Python 3.5

* Tue Sep 22 2015 philippem <philippem> 18.3.2-1.mga6
+ Revision: 882283
- first step for Python 3.5, disable test and wheel
- update to 18.3.2, first step for Python 3.5

* Thu Sep 10 2015 philippem <philippem> 18.3.1-1.mga6
+ Revision: 875719
- update to 18.3.1

* Fri Aug 28 2015 philippem <philippem> 18.2-1.mga6
+ Revision: 870509
- update to 18.2

* Wed Oct 15 2014 umeabot <umeabot> 3.6-7.mga5
+ Revision: 749886
- Second Mageia 5 Mass Rebuild

* Sat Sep 27 2014 tv <tv> 3.6-6.mga5
+ Revision: 729758
- rebuild for missing pythoneggs deps

* Tue Sep 16 2014 umeabot <umeabot> 3.6-5.mga5
+ Revision: 688327
- Mageia 5 Mass Rebuild

* Mon Jun 02 2014 philippem <philippem> 3.6-4.mga5
+ Revision: 630642
- add egg provides
+ pterjan <pterjan>
- Rebuild for new Python

* Sat May 24 2014 philippem <philippem> 3.6-2.mga5
+ Revision: 625288
- Rebuild as wheel for Python 3.4

* Fri May 23 2014 philippem <philippem> 3.6-1.mga5
+ Revision: 625212
- update to 3.6, first step for Python 3.4

* Wed Apr 23 2014 philippem <philippem> 3.4.4-1.mga5
+ Revision: 617546
- update to 3.4.4

* Tue Apr 01 2014 philippem <philippem> 3.4.1-1.mga5
+ Revision: 611212
- update to 3.4.1

* Tue Mar 04 2014 philippem <philippem> 2.2-1.mga5
+ Revision: 599547
- update to 2.2

* Tue Nov 05 2013 philippem <philippem> 1.3-1.mga4
+ Revision: 549629
- Update to 1.3

* Tue Oct 22 2013 umeabot <umeabot> 1.1.6-3.mga4
+ Revision: 544250
- Mageia 4 Mass Rebuild

* Tue Oct 15 2013 pterjan <pterjan> 1.1.6-2.mga4
+ Revision: 499362
- Rebuild to add different pythonegg provides for python 2 and 3

* Wed Sep 25 2013 philippem <philippem> 1.1.6-1.mga4
+ Revision: 486390
- Update to 1.1.6

* Sun Aug 25 2013 philippem <philippem> 1.0-1.mga4
+ Revision: 471705
- update to 1.0

* Wed Jul 17 2013 philippem <philippem> 0.9.5-1.mga4
+ Revision: 455199
- Update to 0.9.5
  - package_index can handle hashes other than md5
  - Fix security vulnerability in SSL certificate validation

* Thu Jul 11 2013 philippem <philippem> 0.8-1.mga4
+ Revision: 453030
- Update to the setuptools-0.8 branch that merges distribute and setuptools

* Sat Jun 08 2013 philippem <philippem> 0.6.45-1.mga4
+ Revision: 440665
- new upstream

* Fri Feb 08 2013 anssi <anssi> 0.6.28-6.mga3
+ Revision: 395526
- versionize Obsoletes to avoid any future issues

* Mon Feb 04 2013 spuhler <spuhler> 0.6.28-5.mga3
+ Revision: 394464
- added Obsoletes: python-distribute

* Sat Jan 26 2013 dmorgan <dmorgan> 0.6.28-4.mga3
+ Revision: 392538
- Rebuild to add missing rpm
+ umeabot <umeabot>
- Mass Rebuild - https://wiki.mageia.org/en/Feature:Mageia3MassRebuild

* Sat Sep 29 2012 fwang <fwang> 0.6.28-2.mga3
+ Revision: 300324
- rebuild for new py3.3

* Mon Aug 13 2012 lebedov <lebedov> 0.6.28-1.mga3
+ Revision: 281173
- Update to 0.6.28.

* Mon Mar 12 2012 kamil <kamil> 0.6.24-2.mga2
+ Revision: 223161
- python 3 build
- update license (according to Fedora)

* Wed Oct 26 2011 philippem <philippem> 0.6.24-1.mga2
+ Revision: 158282
- Upstream bugfix release 0.6.24

* Sun Jun 19 2011 kharec <kharec> 0.6.19-1.mga2
+ Revision: 109701
- new version 0.6.19

* Fri Feb 18 2011 ahmad <ahmad> 0.6.14-7.mga1
+ Revision: 53912
- rebuild so that the pythonegg autoprovides become available

* Mon Jan 17 2011 pterjan <pterjan> 0.6.14-6.mga1
+ Revision: 21275
- Rebuild for python 2.7

* Sun Jan 09 2011 blino <blino> 0.6.14-5.mga1
+ Revision: 3687
- remove old conflicts
- imported package python-setuptools


* Mon Nov 01 2010 Funda Wang <fwang@mandriva.org> 0.6.14-4mdv2011.0
+ Revision: 591551
- wrong req on python-sqlalchemy

* Sun Oct 31 2010 Funda Wang <fwang@mandriva.org> 0.6.14-3mdv2011.0
+ Revision: 591061
- add requires on python-sqlalchemy for tuntime

* Sat Oct 30 2010 Andrey Borzenkov <arvidjaar@mandriva.org> 0.6.14-2mdv2011.0
+ Revision: 590349
- rebuild with new python 2.7

* Fri Oct 29 2010 Funda Wang <fwang@mandriva.org> 0.6.14-1mdv2011.0
+ Revision: 589963
- New fork distribute

* Sat Nov 07 2009 Frederik Himpe <fhimpe@mandriva.org> 0.6c11-1mdv2010.1
+ Revision: 462167
- Update to non-broken version 0.6c11

* Mon Oct 19 2009 Lev Givon <lev@mandriva.org> 0.6c10-1mdv2010.1
+ Revision: 458285
- Update to 0.6c10.

* Wed Dec 24 2008 Michael Scherer <misc@mandriva.org> 0.6c9-3mdv2009.1
+ Revision: 318435
- rebuild for new python

* Fri Nov 28 2008 Wanderlei Cavassin <cavassin@mandriva.com.br> 0.6c9-2mdv2009.1
+ Revision: 307480
- Splitted python-pkg-resources, then packages like elisa will not
  need to drag python-devel and others.

* Mon Oct 27 2008 Lev Givon <lev@mandriva.org> 0.6c9-1mdv2009.1
+ Revision: 297704
- Update to 0.6c9.
  Remove patch (included in 0.6c9).

  + Tomasz Pawel Gajc <tpg@mandriva.org>
    - remuve stupid redefines
    - fix mixture of tabs and spaces
    - better description
    - export CFLAGS
    - enable checks

* Tue Jul 08 2008 Colin Guthrie <cguthrie@mandriva.org> 0.6c8-3mdv2009.0
+ Revision: 232866
- Apply patch to fix bug when working with subversion 1.5 checkouts

* Sat Jul 05 2008 Funda Wang <fwang@mandriva.org> 0.6c8-2mdv2009.0
+ Revision: 231966
- setuptools requires python2.5/config/Makefile to work

* Thu Feb 21 2008 Lev Givon <lev@mandriva.org> 0.6c8-1mdv2008.1
+ Revision: 173464
- Update to 0.6c8.

  + Olivier Blin <oblin@mandriva.com>
    - restore BuildRoot

  + Thierry Vignaud <tv@mandriva.org>
    - kill re-definition of %%buildroot on Pixel's request

* Wed Nov 07 2007 Lev Givon <lev@mandriva.org> 0.6c7-2mdv2008.1
+ Revision: 106628
- Fix file installation issue.

* Thu Oct 11 2007 Lev Givon <lev@mandriva.org> 0.6c7-1mdv2008.1
+ Revision: 97177
- Update to 0.6c7.

* Mon Jun 18 2007 Lev Givon <lev@mandriva.org> 0.6c6-1mdv2008.0
+ Revision: 41112
- Update to 0.6c6.

* Tue Apr 24 2007 Lev Givon <lev@mandriva.org> 0.6c5-1mdv2008.0
+ Revision: 17935
- Update to 0.6c5.


* Fri Jan 05 2007 Michael Scherer <misc@mandriva.org> 0.6c3-1mdv2007.0
+ Revision: 104332
- upgrade to 0.6c3
- use %%rel for mkrel

* Wed Nov 29 2006 Michael Scherer <misc@mandriva.org> 0.6a11-2mdv2007.1
+ Revision: 88724
- rebuild for new python
- Import python-setuptools

